==> certmanager-model-v1alpha2-6.1.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ChallengeListFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ChallengeListFluent<A extends ChallengeListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Challenge item);
  public A setToItems(Integer index,Challenge item);
  public A addToItems(io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge... items);
  public A addAllToItems(Collection<Challenge> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge... items);
  public A removeAllFromItems(Collection<Challenge> items);
  public A removeMatchingFromItems(Predicate<ChallengeBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Challenge> getItems();
  public List<Challenge> buildItems();
  public Challenge buildItem(Integer index);
  public Challenge buildFirstItem();
  public Challenge buildLastItem();
  public Challenge buildMatchingItem(Predicate<ChallengeBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ChallengeBuilder> predicate);
  public A withItems(List<Challenge> items);
  public A withItems(io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge... items);
  public Boolean hasItems();
  public ChallengeListFluent.ItemsNested<A> addNewItem();
  public ChallengeListFluent.ItemsNested<A> addNewItemLike(Challenge item);
  public ChallengeListFluent.ItemsNested<A> setNewItemLike(Integer index,Challenge item);
  public ChallengeListFluent.ItemsNested<A> editItem(Integer index);
  public ChallengeListFluent.ItemsNested<A> editFirstItem();
  public ChallengeListFluent.ItemsNested<A> editLastItem();
  public ChallengeListFluent.ItemsNested<A> editMatchingItem(Predicate<ChallengeBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ChallengeFluent<ChallengeListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ChallengeListFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ChallengeListFluent<A extends ChallengeListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Challenge item);
  public A setToItems(int index,Challenge item);
  public A addToItems(io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge... items);
  public A addAllToItems(Collection<Challenge> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge... items);
  public A removeAllFromItems(Collection<Challenge> items);
  public A removeMatchingFromItems(Predicate<ChallengeBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Challenge> getItems();
  public List<Challenge> buildItems();
  public Challenge buildItem(int index);
  public Challenge buildFirstItem();
  public Challenge buildLastItem();
  public Challenge buildMatchingItem(Predicate<ChallengeBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ChallengeBuilder> predicate);
  public A withItems(List<Challenge> items);
  public A withItems(io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge... items);
  public Boolean hasItems();
  public ChallengeListFluent.ItemsNested<A> addNewItem();
  public ChallengeListFluent.ItemsNested<A> addNewItemLike(Challenge item);
  public ChallengeListFluent.ItemsNested<A> setNewItemLike(int index,Challenge item);
  public ChallengeListFluent.ItemsNested<A> editItem(int index);
  public ChallengeListFluent.ItemsNested<A> editFirstItem();
  public ChallengeListFluent.ItemsNested<A> editLastItem();
  public ChallengeListFluent.ItemsNested<A> editMatchingItem(Predicate<ChallengeBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ChallengeFluent<ChallengeListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
